## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Unset -s on python shebang - ensure that extensions installed with pip
# to user locations are seen and properly loaded
%global py3_shebang_flags %(echo %py3_shebang_flags | sed s/s//)

Name:           python-notebook
Version:        7.4.0
Release:        %autorelease
Summary:        A web-based notebook environment for interactive computing
# SPDX
License:        BSD-3-Clause
URL:            https://jupyter.org
Source:         %{pypi_source notebook}

BuildArch:      noarch

BuildRequires:  python3-devel
# For validating desktop entry
BuildRequires:  desktop-file-utils

%global _description \
The Jupyter Notebook is a web application that allows you to create and \
share documents that contain live code, equations, visualizations, and \
explanatory text. The Notebook has support for multiple programming \
languages, sharing, and interactive widgets.

%description %_description

%package -n     python3-notebook
Summary:        %{summary}
Requires:       python-jupyter-filesystem
%py_provides    python3-jupyter-notebook
%py_provides    python3-ipython-notebook
%py_provides    notebook
%py_provides    jupyter-notebook
# We stopped shipping doc a long time ago, but there are possible conflicts.
# For details, see https://bugzilla.redhat.com/2254087
# (Keep this around at least until Fedora 41.)
Obsoletes:      python-notebook-doc < 7

%description -n python3-notebook %_description


%prep
%autosetup -p1 -n notebook-%{version}

# The nbval package is used for validation of notebooks.
# It's sedded out because it isn't yet packaged in Fedora.
# Selenium tests are skipped because the version in Fedora is too old.
# We don't test coverage.
# pytest-tornasync is unmaintained upstream and will be
# replaced by pytest-jupyter.
for pkg in nbval "selenium==.*" coverage pytest-cov pytest-tornasync; do
  sed -Ei "/\"$pkg\",?/d" pyproject.toml
done

# Remove all backup files
find ./ -name "*.json.orig" -delete

%generate_buildrequires
%pyproject_buildrequires -x test


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files notebook

install -m 0755 -p -d %{buildroot}%{_sysconfdir}/jupyter/jupyter_server_config.d
mv -v %{buildroot}{%{_prefix},}%{_sysconfdir}/jupyter/jupyter_server_config.d/notebook.json

%check
%pytest -W ignore::DeprecationWarning --ignore notebook/tests/selenium

desktop-file-validate %{buildroot}%{_datadir}/applications/jupyter-notebook.desktop


%files -n python3-notebook -f %{pyproject_files}
%doc README.md
%license LICENSE
%{_bindir}/jupyter-notebook
%config(noreplace) %{_sysconfdir}/jupyter/jupyter_server_config.d/notebook.json
%{_datadir}/jupyter/lab/schemas/@jupyter-notebook/
%{_datadir}/jupyter/labextensions/@jupyter-notebook/
%{_datadir}/applications/jupyter-notebook.desktop
%{_datadir}/icons/hicolor/scalable/apps/notebook.svg

%changelog
## START: Generated by rpmautospec
* Wed Apr 09 2025 Lumir Balhar <lbalhar@redhat.com> - 7.4.0-1
- Update to 7.4.0 (rhbz#2358684)

* Wed Mar 26 2025 Lumir Balhar <lbalhar@redhat.com> - 7.3.3-1
- Update to 7.3.3 (rhbz#2352574)

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 7.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Mon Jan 06 2025 Lumir Balhar <lbalhar@redhat.com> - 7.3.2-1
- Update to 7.3.2 (rhbz#2333637)

* Sat Dec 07 2024 Lumir Balhar <lbalhar@redhat.com> - 7.3.1-1
- Update to 7.3.1 (rhbz#2330305)

* Thu Sep 12 2024 Lumir Balhar <lbalhar@redhat.com> - 7.2.2-1
- Update to 7.2.2 (rhbz#2284126)

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 7.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Mon Jun 17 2024 Python Maint <python-maint@redhat.com> - 7.2.0-2
- Rebuilt for Python 3.13

* Sat May 25 2024 Lumir Balhar <lbalhar@redhat.com> - 7.2.0-1
- Update to 7.2.0 (rhbz#2272220)

* Fri Mar 15 2024 Lumir Balhar <lbalhar@redhat.com> - 7.1.2-1
- Update to 7.1.2 (rhbz#2266069)

* Tue Feb 13 2024 Lumir Balhar <lbalhar@redhat.com> - 7.1.0-1
- Update to 7.1.0 (rhbz#2260490)

* Tue Jan 23 2024 Lumir Balhar <lbalhar@redhat.com> - 7.0.7-1
- Update to 7.0.7 (rhbz#2252762)

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Dec 12 2023 Miro Hrončok <miro@hroncok.cz> - 7.0.6-2
- Obsolete python-notebook-doc < 7
- Don't put README.md and LICENSE to a custom folder
- Fixes: rhbz#2254087

* Wed Oct 18 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.6-1
- Update to 7.0.6 (rhbz#2244640)

* Thu Oct 12 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.5-1
- Update to 7.0.5 (rhbz#2243621)

* Wed Sep 20 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.4-1
- Update to 7.0.4 (rhbz#2239795)

* Wed Sep 06 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.3-1
- Update to 7.0.3 (rhbz#2236193)

* Mon Aug 07 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.2-1
- Update to 7.0.2 (rhbz#2227825)

* Thu Aug 03 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.1-1
- Update to 7.0.1 (rhbz#2227825)

* Thu Jul 20 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.0-1
- Update to 7.0.0 (rhbz#2224039)

* Mon Jul 10 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.0rc2-1
- Update to 7.0.0 RC2

* Mon Jul 10 2023 Miro Hrončok <miro@hroncok.cz> - 7.0.0b3-3
- Workaround a possible Python 3.12 regression in importlib.resources

* Tue Jul 04 2023 Python Maint <python-maint@redhat.com> - 7.0.0b3-2
- Rebuilt for Python 3.12

* Thu Jun 01 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.0b3-1
- Update to 7.0.0 beta 3 (rhbz#2184443)

* Wed Mar 29 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.0a18-1
- Update to 7.0.0a18 (rhbz#2181597)

* Wed Mar 22 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.0a17-1
- Update to 7.0.0 alpha 17 (rhbz#2178583)

* Fri Mar 10 2023 Lumir Balhar <lbalhar@redhat.com> - 7.0.0a15-1
- Update to 7.0.0a15

* Mon Mar 06 2023 Lumír Balhar <lbalhar@redhat.com> - 6.5.3-1
- Update to 6.5.3 (rhbz#2062405)

* Wed Feb 01 2023 Lumír Balhar <lbalhar@redhat.com> - 6.5.2-1
- Update to 6.5.2 (#2062405)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 6.4.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Aug 03 2022 Karolina Surma <ksurma@redhat.com> - 6.4.12-1
- Update to 6.4.12

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.4.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jul 13 2022 Miro Hrončok <mhroncok@redhat.com> - 6.4.11-3
- Fix CVE-2022-24785 and CVE-2022-31129 in bundled moment
- Fixes: rhbz#2075263

* Thu Jun 16 2022 Python Maint <python-maint@redhat.com> - 6.4.11-2
- Rebuilt for Python 3.11

* Mon May 30 2022 Miro Hrončok <mhroncok@redhat.com> - 6.4.11-1
- Update to 6.4.11

* Tue Mar 22 2022 Miro Hrončok <mhroncok@redhat.com> - 6.4.10-1
- Update to 6.4.10

* Tue Jan 25 2022 Miro Hrončok <mhroncok@redhat.com> - 6.4.8-1
- Update to 6.4.8
- Fixes: rhbz#2045852

* Tue Jan 25 2022 Miro Hrončok <mhroncok@redhat.com> - 6.4.7-1
- Update to 6.4.7
- Fixes: rhbz#2039905

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.4.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Nov 29 2021 Karolina Surma <ksurma@redhat.com> - 6.4.6-2
- Remove -s from Python shebang in `jupyter-*` executables
  to let Jupyter see pip installed extensions

* Wed Nov 24 2021 Karolina Surma <ksurma@redhat.com> - 6.4.6-1
- Update to 6.4.6
Resolves: rhbz#2023994

* Tue Oct 26 2021 Lumír Balhar <lbalhar@redhat.com> - 6.4.5-1
- Update to 6.4.5
Resolves: rhbz#2004590

* Wed Aug 11 2021 Tomas Hrnciar <thrnciar@redhat.com> - 6.4.3-1
- Update to 6.4.3
- Fixes: rhbz#1990615
- Fixes: rhbz#1992573

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 6.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Thu Jun 24 2021 Lumír Balhar <lbalhar@redhat.com> - 6.4.0-1
- Update to 6.4.0
Resolves: rhbz#1956754

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 6.3.0-2
- Rebuilt for Python 3.10

* Tue Mar 23 2021 Karolina Surma <ksurma@redhat.com> - 6.3.0-1
- Update to 6.3.0
Resolves: rhbz#1941573
- Add desktop entry
Resolves: rhbz#1275800
- Remove documentation subpackage

* Thu Feb 18 2021 Lumír Balhar <lbalhar@redhat.com> - 6.2.0-1
- Update to 6.2.0
Resolves: rhbz#1915896

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Jan 07 2021 Miro Hrončok <mhroncok@redhat.com> - 6.1.6-1
- Update to 6.1.6
- Fixes: rhbz#1895357

* Thu Sep 10 2020 Tomas Hrnciar <thrnciar@redhat.com> - 6.1.4-1
- Update to 6.1.4
- fixes rhbz#1844874

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jun 11 2020 Miro Hrončok <mhroncok@redhat.com> - 6.0.3-7
- Remove packaged tests

* Mon May 25 2020 Miro Hrončok <mhroncok@redhat.com> - 6.0.3-6
- Rebuilt for Python 3.9

* Sat Apr 18 2020 Miro Hrončok <mhroncok@redhat.com> - 6.0.3-5
- Update to 6.0.3 (#1793671)

* Thu Mar 12 2020 Miro Hrončok <mhroncok@redhat.com> - 6.0.2-4
- Workaround RPM problems when replacing a directory with a symbolic link (#1787079)

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Dec 26 2019 Miro Hrončok <mhroncok@redhat.com> - 6.0.2-2
- Use bundled JavaScript moment, the Fedora one was retired

* Tue Nov 12 2019 Miro Hrončok <mhroncok@redhat.com> - 6.0.2-1
- Update to 6.0.2 (#1724407)

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 5.7.8-4
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Sun Aug 18 2019 Miro Hrončok <mhroncok@redhat.com> - 5.7.8-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.7.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Apr 01 2019 Miro Hrončok <mhroncok@redhat.com> - 5.7.8-1
- Update to 5.7.8, refix CVE-2019-10255

* Sun Mar 31 2019 Miro Hrončok <mhroncok@redhat.com> - 5.7.7-1
- Update to 5.7.7, fix CVE-2019-9644 and CVE-2019-10255

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.7.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Nov 21 2018 Miro Hrončok <mhroncok@redhat.com> - 5.7.2-1
- Update to 5.7.2, fix CVE-2018-19351, CVE-2018-19352 (#1651976)

* Wed Nov 07 2018 Miro Hrončok <mhroncok@redhat.com> - 5.6.0-3
- Drop the python2 leaf subpackage again (#1647377)

* Mon Aug 13 2018 Miro Hrončok <mhroncok@redhat.com> - 5.6.0-2
- Require mathjax from python3-notebook (#1615192)

* Mon Jul 23 2018 Miro Hrončok <mhroncok@redhat.com> - 5.6.0-1
- Update to 5.6.0 (#1601163)

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.5.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 5.5.0-6
- Rebuilt for Python 3.7

* Tue Jun 05 2018 Miro Hrončok <mhroncok@redhat.com> - 5.5.0-5
- Reintroduce the python2 subpackage for sagemath

* Sun May 27 2018 Miro Hrončok <mhroncok@redhat.com> - 5.5.0-4
- Drop the python2 leaf subpackage

* Sat May 26 2018 Jonathan Underwood <jonathan.underwood@gmail.com> - 5.5.0-3
- Unbundle mathjax once more
- Add patch to use the MathJax TeX fonts rather than the STIXWeb ones BZ: 1581899, 1580129

* Wed May 23 2018 Miro Hrončok <mhroncok@redhat.com> - 5.5.0-2
- BR ipykernel >= 4.8 (#1581723)
- Temporarily keep bundled mathjax (#1580129)

* Fri May 11 2018 Miro Hrončok <mhroncok@redhat.com> - 5.5.0-1
- Update to 5.5.0 (#1557990)
- Disable selenium tests and rm them from python2 sitelib

* Wed Mar 21 2018 Miro Hrončok <mhroncok@redhat.com> - 5.4.0-2
- Security fix for CVE-2018-8768 (#1558783)

* Wed Feb 21 2018 Miro Hrončok <mhroncok@redhat.com> - 5.4.0-1
- Update to 5.4.0 (#1535263)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 19 2018 Miro Hrončok <mhroncok@redhat.com> - 5.3.0-1
- Update to 5.3.0
- Enable automatic dependency generator, drop manual Python requires

* Tue Jan 09 2018 Miro Hrončok <mhroncok@redhat.com> - 5.3.0-0.1.rc1
- Update to new 5.3.0rc1 version (#1532430)
- Only BR git-core instead of full git, it is sufficient
- Be more explciit about (Build)Required versions
- Require send2trash, dateutil

* Thu Nov 23 2017 Miro Hrončok <mhroncok@redhat.com> - 5.2.1-1
- Update to new 5.2.1 version (#1504386)

* Fri Sep 15 2017 Miro Hrončok <mhroncok@redhat.com> - 5.1.0-1
- Update to new 5.1.0 final version (#1491890)

* Tue Sep 12 2017 Miro Hrončok <mhroncok@redhat.com> - 5.1.0-0.2.rc3
- Update to new 5.1.0rc3 version (#1490880)
- Remove 2 merged patches

* Wed Aug 23 2017 Miro Hrončok <mhroncok@redhat.com> - 5.1.0-0.1.rc2
- Update to new 5.1.0rc2 version (#1482722)
- Use node to compile JS and CSS

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Apr 04 2017 Miro Hrončok <mhroncok@redhat.com> - 5.0.0-1
- Update to new 5.0.0 version (#1438917)
- Use autosetup with git
- Add the license file to the doc subpackage

* Fri Mar 17 2017 Miro Hrončok <mhroncok@redhat.com> - 4.4.1-3
- Recommend terminado

* Tue Feb 21 2017 Miro Hrončok <mhroncok@redhat.com> - 4.4.1-2
- Make sure the Python 3 executables are really Python 3
- Build the docs
- Run the tests
- Use python2- where possible
- Unbundle some things, declare the rest
- Use the %%_description macro consistently
- Provide pythonX-jupyter-notebook
- Provide/Obsolete pythonX-ipython-notebook

* Thu Feb 09 2017 Thomas Spura <tomspur@fedoraproject.org> - 4.4.1-1
- rename to python-notebook
- only ship python3 executables
- update to 4.4.1

* Mon Apr 18 2016 Thomas Spura <tomspur@fedoraproject.org> - 4.2.0-1
- Initial package.

## END: Generated by rpmautospec
